@@ -151,7 +151,7 @@ sub store_device {
   }
 
   my @properties = qw/
-    snmp_ver snmp_comm
+    snmp_ver
     description uptime contact name location
     layers ports mac serial model
     ps1_type ps2_type ps1_status ps2_status
@@ -168,7 +168,7 @@ sub store_device {
 
   schema('netdisco')->txn_do(sub {
     my $gone = $device->device_ips->delete;
-    debug sprintf ' [%s] device - removed %s aliases',
+    debug sprintf ' [%s] device - removed %d aliases',
       $device->ip, $gone;
     $device->update_or_insert(undef, {for => 'update'});
     $device->device_ips->populate($resolved_aliases);
@@ -282,9 +282,9 @@ sub store_interfaces {
       };
   }
 
-  schema('netdisco')->txn_do(sub {
+  schema('netdisco')->resultset('DevicePort')->txn_do_locked(sub {
     my $gone = $device->ports->delete({keep_nodes => 1});
-    debug sprintf ' [%s] interfaces - removed %s interfaces',
+    debug sprintf ' [%s] interfaces - removed %d interfaces',
       $device->ip, $gone;
     $device->update_or_insert(undef, {for => 'update'});
     $device->ports->populate([values %interfaces]);
@@ -337,7 +337,7 @@ sub store_wireless {
 
   schema('netdisco')->txn_do(sub {
     my $gone = $device->ssids->delete;
-    debug sprintf ' [%s] wireless - removed %s SSIDs',
+    debug sprintf ' [%s] wireless - removed %d SSIDs',
       $device->ip, $gone;
     $device->ssids->populate(\@ssids);
     debug sprintf ' [%s] wireless - added %d new SSIDs',
@@ -364,7 +364,7 @@ sub store_wireless {
 
   schema('netdisco')->txn_do(sub {
     my $gone = $device->wireless_ports->delete;
-    debug sprintf ' [%s] wireless - removed %s wireless channels',
+    debug sprintf ' [%s] wireless - removed %d wireless channels',
       $device->ip, $gone;
     $device->wireless_ports->populate(\@channels);
     debug sprintf ' [%s] wireless - added %d new wireless channels',
@@ -439,7 +439,7 @@ sub store_vlans {
 
   schema('netdisco')->txn_do(sub {
     my $gone = $device->vlans->delete;
-    debug sprintf ' [%s] vlans - removed %s device VLANs',
+    debug sprintf ' [%s] vlans - removed %d device VLANs',
       $device->ip, $gone;
     $device->vlans->populate(\@devicevlans);
     debug sprintf ' [%s] vlans - added %d new device VLANs',
@@ -448,7 +448,7 @@ sub store_vlans {
 
   schema('netdisco')->txn_do(sub {
     my $gone = $device->port_vlans->delete;
-    debug sprintf ' [%s] vlans - removed %s port VLANs',
+    debug sprintf ' [%s] vlans - removed %d port VLANs',
       $device->ip, $gone;
     $device->port_vlans->populate(\@portvlans);
     debug sprintf ' [%s] vlans - added %d new port VLANs',
@@ -515,7 +515,7 @@ sub store_power {
 
   schema('netdisco')->txn_do(sub {
     my $gone = $device->power_modules->delete;
-    debug sprintf ' [%s] power - removed %s power modules',
+    debug sprintf ' [%s] power - removed %d power modules',
       $device->ip, $gone;
     $device->power_modules->populate(\@devicepower);
     debug sprintf ' [%s] power - added %d new power modules',
@@ -524,7 +524,7 @@ sub store_power {
 
   schema('netdisco')->txn_do(sub {
     my $gone = $device->powered_ports->delete;
-    debug sprintf ' [%s] power - removed %s PoE capable ports',
+    debug sprintf ' [%s] power - removed %d PoE capable ports',
       $device->ip, $gone;
     $device->powered_ports->populate(\@portpower);
     debug sprintf ' [%s] power - added %d new PoE capable ports',
@@ -572,23 +572,23 @@ sub store_modules {
           index  => $e_index->{$entry},
           type   => $e_type->{$entry},
           parent => $e_parent->{$entry},
-          name   => $e_name->{$entry},
+          name   => Encode::decode('UTF-8', $e_name->{$entry}),
           class  => $e_class->{$entry},
           pos    => $e_pos->{$entry},
           hw_ver => Encode::decode('UTF-8', $e_hwver->{$entry}),
           fw_ver => Encode::decode('UTF-8', $e_fwver->{$entry}),
           sw_ver => Encode::decode('UTF-8', $e_swver->{$entry}),
           model  => Encode::decode('UTF-8', $e_model->{$entry}),
-          serial => $e_serial->{$entry},
+          serial => Encode::decode('UTF-8', $e_serial->{$entry}),
           fru    => $e_fru->{$entry},
-          description => $e_descr->{$entry},
+          description => Encode::decode('UTF-8', $e_descr->{$entry}),
           last_discover => \'now()',
       };
   }
 
   schema('netdisco')->txn_do(sub {
     my $gone = $device->modules->delete;
-    debug sprintf ' [%s] modules - removed %s chassis modules',
+    debug sprintf ' [%s] modules - removed %d chassis modules',
       $device->ip, $gone;
     $device->modules->populate(\@modules);
     debug sprintf ' [%s] modules - added %d new chassis modules',
@@ -617,7 +617,7 @@ sub store_neighbors {
   my ($device, $snmp) = @_;
   my @to_discover = ();
 
-  # first allow any manually configred topology to be set
+  # first allow any manually configured topology to be set
   _set_manual_topology($device, $snmp);
 
   my $c_ip = $snmp->c_ip;
@@ -631,6 +631,7 @@ sub store_neighbors {
   my $c_port     = $snmp->c_port;
   my $c_id       = $snmp->c_id;
   my $c_platform = $snmp->c_platform;
+  my $c_cap      = $snmp->c_cap;
 
   foreach my $entry (keys %$c_ip) {
       my $port = $interfaces->{ $c_if->{$entry} };
@@ -645,6 +646,7 @@ sub store_neighbors {
       my $remote_port = undef;
       my $remote_type = $c_platform->{$entry};
       my $remote_id   = Encode::decode('UTF-8', $c_id->{$entry});
+      my $remote_cap  = $c_cap->{$entry} || [];
 
       next unless $remote_ip;
 
@@ -684,13 +686,20 @@ sub store_neighbors {
           }
       }
 
-      # IP Phone detection type fixup
-      if (defined $remote_type and $remote_type =~ m/(mitel.5\d{3})/i) {
-          $remote_type = 'IP Phone - '. $remote_type
+      # IP Phone and WAP detection type fixup
+      if (defined $remote_type) {
+        my $phone_flag = grep {/phone/i} @$remote_cap;
+        my $ap_flag = grep {/wlanAccessPoint/} @$remote_cap;
+        if ($phone_flag or $remote_type =~ m/(mitel.5\d{3})/i) {
+          $remote_type = 'IP Phone: '. $remote_type
             if $remote_type !~ /ip phone/i;
-      }
-      else {
+        }
+        elsif ($ap_flag) {
+          $remote_type = 'AP: '. $remote_type;          
+        }
+        else {
           $remote_type ||= '';
+        }
       }
 
       # hack for devices seeing multiple neighbors on the port
@@ -848,14 +857,21 @@ sub discover_new_neighbors {
           next;
       }
 
-      # could fail if queued job already exists
-      try {
-          schema('netdisco')->resultset('Admin')->create({
-              device => $ip,
+      # Don't queued if job already exists
+      my $is_queued = schema('netdisco')->resultset('Admin')->search(
+          {   device => $ip,
               action => 'discover',
-              status => 'queued',
-          });
-      };
+              status => { -like => 'queued%' },
+          }
+      )->single;
+      unless ($is_queued) {
+          schema('netdisco')->resultset('Admin')->create(
+              {   device => $ip,
+                  action => 'discover',
+                  status => 'queued',
+              }
+          );
+      }
   }
 }
 
