@@ -37,8 +37,11 @@ sub with_times {
           uptime_age => \("replace(age(timestamp 'epoch' + uptime / 100 * interval '1 second', "
             ."timestamp '1970-01-01 00:00:00-00')::text, 'mon', 'month')"),
           last_discover_stamp => \"to_char(last_discover, 'YYYY-MM-DD HH24:MI')",
-          last_macsuck_stamp => \"to_char(last_macsuck,  'YYYY-MM-DD HH24:MI')",
-          last_arpnip_stamp => \"to_char(last_arpnip,   'YYYY-MM-DD HH24:MI')",
+          last_macsuck_stamp  => \"to_char(last_macsuck,  'YYYY-MM-DD HH24:MI')",
+          last_arpnip_stamp   => \"to_char(last_arpnip,   'YYYY-MM-DD HH24:MI')",
+          since_last_discover => \"extract(epoch from (age(now(), last_discover)))",
+          since_last_macsuck  => \"extract(epoch from (age(now(), last_macsuck)))",
+          since_last_arpnip   => \"extract(epoch from (age(now(), last_arpnip)))",
         },
       });
 }
@@ -196,7 +199,7 @@ sub search_by_field {
 
     # this is a bit of an inelegant trick to catch junk data entry,
     # whilst avoiding returning *all* entries in the table
-    if (length $p->{ip} and 'NetAddr::IP::Lite' ne ref $p->{ip}) {
+    if ($p->{ip} and 'NetAddr::IP::Lite' ne ref $p->{ip}) {
       $p->{ip} = ( NetAddr::IP::Lite->new($p->{ip})
         || NetAddr::IP::Lite->new('255.255.255.255') );
     }
@@ -349,8 +352,9 @@ sub carrying_vlan {
     die "vlan number required for carrying_vlan\n"
       if ref {} ne ref $cond or !exists $cond->{vlan};
 
-    $cond->{'vlans.vlan'} = $cond->{vlan};
-    $cond->{'port_vlans.vlan'} = delete $cond->{vlan};
+    $cond->{'-and'} ||= [];
+    push @{$cond->{'-and'}}, 'vlans.vlan' => $cond->{vlan};
+    push @{$cond->{'-and'}}, 'port_vlans.vlan' => delete $cond->{vlan};
 
     return $rs
       ->search_rs($cond,
@@ -399,7 +403,7 @@ sub carrying_vlan_name {
     die "vlan name required for carrying_vlan_name\n"
       if ref {} ne ref $cond or !exists $cond->{name};
 
-    $cond->{'vlans.description'} = { '-ilike' => $cond->{name} };
+    $cond->{'vlans.description'} = { '-ilike' => delete $cond->{name} };
 
     return $rs
       ->search_rs({}, {
@@ -491,4 +495,185 @@ sub get_distinct_col {
   )->get_column($col)->all;
 }
 
+=head2 with_port_count
+
+This is a modifier for any C<search()> which
+will add the following additional synthesized column to the result set:
+
+=over 4
+
+=item port_count
+
+=back
+
+=cut
+
+sub with_port_count {
+  my ($rs, $cond, $attrs) = @_;
+
+  return $rs
+    ->search_rs($cond, $attrs)
+    ->search({},
+      {
+        '+columns' => {
+          port_count =>
+            $rs->result_source->schema->resultset('DevicePort')
+              ->search(
+                {
+                  'dp.ip' => { -ident => 'me.ip' },
+                  'dp.type' => { '!=' => 'propVirtual' },
+                },
+                { alias => 'dp' }
+              )->count_rs->as_query,
+        },
+      });
+}
+
+=head1 SPECIAL METHODS
+
+=head2 delete( \%options? )
+
+Overrides the built-in L<DBIx::Class> delete method to more efficiently
+handle the removal or archiving of nodes.
+
+=cut
+
+sub delete {
+  my $self = shift;
+
+  my $schema = $self->result_source->schema;
+  my $devices = $self->search(undef, { columns => 'ip' });
+
+  foreach my $set (qw/
+    DeviceIp
+    DeviceVlan
+    DevicePower
+    DeviceModule
+  /) {
+      $schema->resultset($set)->search(
+        { ip => { '-in' => $devices->as_query } },
+      )->delete;
+  }
+
+  $schema->resultset('Community')->search({
+    ip => { '-in' => $devices->as_query },
+    snmp_auth_tag => undef,
+  })->delete;
+
+  $schema->resultset('Community')->search(
+    { ip => { '-in' => $devices->as_query } },
+  )->update({snmp_comm_rw => undef});
+
+  $schema->resultset('Admin')->search({
+    device => { '-in' => $devices->as_query },
+    action => { '-like' => 'queued%' },
+  })->delete;
+
+  $schema->resultset('Topology')->search({
+    -or => [
+      { dev1 => { '-in' => $devices->as_query } },
+      { dev2 => { '-in' => $devices->as_query } },
+    ],
+  })->delete;
+
+  $schema->resultset('DevicePort')->search(
+    { ip => { '-in' => $devices->as_query } },
+  )->delete(@_);
+
+  # now let DBIC do its thing
+  return $self->next::method();
+}
+
+=head2 with_poestats_as_hashref
+
+This is a modifier for C<search()> which returns a list of hash references
+with the power_modules hash augmented with the following statistics as keys:
+
+=over 4
+
+=item capable_ports
+
+Count of ports which have the ability to supply PoE.
+
+=item disabled_ports
+
+Count of ports with PoE administratively disabled.
+
+=item powered_ports
+
+Count of ports which are delivering power.
+
+=item errored_ports
+
+Count of ports either reporting a fault or in test mode.
+
+=item pwr_committed
+
+Total power that has been negotiated and therefore committed on ports
+actively supplying power.
+
+=item pwr_delivering
+
+Total power as measured on ports actively supplying power.
+
+=back
+
+=cut
+
+sub with_poestats_as_hashref {
+  my ( $rs, $cond, $attrs ) = @_;
+
+  my @return = $rs->search(
+    {},
+    { result_class => 'DBIx::Class::ResultClass::HashRefInflator',
+      prefetch     => { power_modules => 'ports' },
+      order_by     => { -asc => [qw/me.ip power_modules.module/] }
+  })->all;
+
+  my $poemax = {
+    'class0' => 15.4,
+    'class1' => 4.0,
+    'class2' => 7.0,
+    'class3' => 15.4,
+    'class4' => 30.0
+  };
+
+  foreach my $device (@return) {
+    foreach my $module (@{$device->{power_modules}}) {
+      $module->{capable_ports}  = 0;
+      $module->{disabled_ports} = 0;
+      $module->{powered_ports}  = 0;
+      $module->{errored_ports}  = 0;
+      $module->{pwr_committed}  = 0;
+      $module->{pwr_delivering} = 0;
+
+      foreach my $port ( @{$module->{ports}} ) {
+        $module->{capable_ports}++;
+
+        if ( $port->{admin} eq 'false' ) {
+          $module->{disabled_ports}++;
+        }
+        elsif ( $port->{status} ne 'searching'
+                and $port->{status} ne 'deliveringPower' )
+            {
+              $module->{errored_ports}++;
+            }
+        elsif ( $port->{status} eq 'deliveringPower' ) {
+            # Default is class0
+            my $class = $port->{class} || 'class0';
+            $module->{powered_ports}++;
+            if ( defined $port->{power} and $port->{power} ) {
+              $module->{pwr_delivering} += int( $port->{power} / 1000 );
+               $module->{pwr_committed}  += $poemax->{ $class };
+            }
+            else {
+              $module->{pwr_committed} += $poemax->{ $class };
+            }
+          }
+        }
+      }
+    }
+  return \@return;
+}
+
 1;
