@@ -179,6 +179,16 @@ $(document).ready(function() {
   $('#navsearchgo').click(function() {
     $('#navsearchgo').parents('form').submit();
   });
+  $('.nd_navsearchgo-specific').click(function(event) {
+    event.preventDefault();
+    if ($('#nq').val()) {
+      $(this).parents('form').append(
+        $(document.createElement('input')).attr('type', 'hidden')
+                                          .attr('name', 'tab')
+                                          .attr('value', $(this).data('tab'))
+      ).submit();
+    }
+  });
 
   // fix green background on search checkboxes
   // https://github.com/twitter/bootstrap/issues/742
